@@ -123,7 +123,7 @@ class Result(object):
         npts (int): if values is None, precreate it to be of this length
         scale (bool): whether or not the value scales by population scale factor
         color (str/arr): default color for plotting (hex or RGB notation)
-        n_strains (int): the number of strains the result is for (0 for results not by strain)
+        n_variants (int): the number of variants the result is for (0 for results not by variant)
 
     **Example**::
 
@@ -133,7 +133,7 @@ class Result(object):
         print(r1.values)
     '''
 
-    def __init__(self, name=None, npts=None, scale=True, color=None, n_strains=0):
+    def __init__(self, name=None, npts=None, scale=True, color=None, n_variants=0):
         self.name =  name  # Name of this result
         self.scale = scale # Whether or not to scale the result by the scale factor
         if color is None:
@@ -143,16 +143,17 @@ class Result(object):
             npts = 0
         npts = int(npts)
 
-        if n_strains>0:
-            self.values = np.zeros((n_strains, npts), dtype=cvd.result_float)
+        if n_variants>0:
+            self.values = np.zeros((n_variants, npts), dtype=cvd.result_float)
         else:
             self.values = np.zeros(npts, dtype=cvd.result_float)
 
-        self.low    = None
-        self.high   = None
+        self.low  = None
+        self.high = None
         return
 
-    def __repr__(self, *args, **kwargs):
+
+    def __repr__(self):
         ''' Use pretty repr, like sc.prettyobj, but displaying full values '''
         output  = sc.prepr(self, skip=['values', 'low', 'high'], use_repr=False)
         output += 'values:\n' + repr(self.values)
@@ -162,28 +163,40 @@ class Result(object):
             output += '\nhigh:\n' + repr(self.high)
         return output
 
-    def __getitem__(self, *args, **kwargs):
-        ''' To allow e.g. result[5] instead of result.values[5] '''
-        return self.values.__getitem__(*args, **kwargs)
 
-    def __setitem__(self, *args, **kwargs):
+    def __getitem__(self, key):
+        ''' To allow e.g. result['high'] instead of result.high, and result[5] instead of result.values[5] '''
+        if isinstance(key, str):
+            output = getattr(self, key)
+        else:
+            output = self.values.__getitem__(key)
+        return output
+
+
+    def __setitem__(self, key, value):
         ''' To allow e.g. result[:] = 1 instead of result.values[:] = 1 '''
-        return self.values.__setitem__(*args, **kwargs)
+        if isinstance(key, str):
+            setattr(self, key, value)
+        else:
+            self.values.__setitem__(key, value)
+        return
+
 
     def __len__(self):
         ''' To allow len(result) instead of len(result.values) '''
         return len(self.values)
 
+
     @property
     def npts(self):
         return len(self.values)
 
 
-def set_metadata(obj):
+def set_metadata(obj, **kwargs):
     ''' Set standard metadata for an object '''
-    obj.created = sc.now()
-    obj.version = cvv.__version__
-    obj.git_info = cvm.git_info()
+    obj.created = kwargs.get('created', sc.now())
+    obj.version = kwargs.get('version', cvv.__version__)
+    obj.git_info = kwargs.get('git_info', cvm.git_info())
     return
 
 
@@ -275,8 +288,7 @@ class BaseSim(ParsObj):
         ''' Set the metadata for the simulation -- creation time and filename '''
         set_metadata(self)
         if simfile is None:
-            datestr = sc.getdate(obj=self.created, dateformat='%Y-%b-%d_%H.%M.%S')
-            self.simfile = f'covasim_{datestr}.sim'
+            self.simfile = 'covasim.sim'
         return
 
 
@@ -355,7 +367,7 @@ class BaseSim(ParsObj):
 
             sim.day('2020-04-05') # Returns 35
         '''
-        return sc.day(day, *args, start_day=self['start_day'])
+        return sc.day(day, *args, start_date=self['start_day'])
 
 
     def date(self, ind, *args, dateformat=None, as_date=False):
@@ -413,16 +425,16 @@ class BaseSim(ParsObj):
         '''
         Get the actual results objects, not other things stored in sim.results.
 
-        If which is 'main', return only the main results keys. If 'strain', return
-        only strain keys. If 'all', return all keys.
+        If which is 'main', return only the main results keys. If 'variant', return
+        only variant keys. If 'all', return all keys.
 
         '''
         keys = []
-        choices = ['main', 'strain', 'all']
+        choices = ['main', 'variant', 'all']
         if which in ['main', 'all']:
             keys += [key for key,res in self.results.items() if isinstance(res, Result)]
-        if which in ['strain', 'all'] and 'strain' in self.results:
-            keys += [key for key,res in self.results['strain'].items() if isinstance(res, Result)]
+        if which in ['variant', 'all'] and 'variant' in self.results:
+            keys += [key for key,res in self.results['variant'].items() if isinstance(res, Result)]
         if which not in choices: # pragma: no cover
             errormsg = f'Choice "which" not available; choices are: {sc.strjoin(choices)}'
             raise ValueError(errormsg)
@@ -592,7 +604,7 @@ class BaseSim(ParsObj):
             An sc.Spreadsheet with an Excel file, or writes the file to disk
         '''
         if skip_pars is None:
-            skip_pars = ['strain_map', 'vaccine_map'] # These include non-string keys so fail at sc.flattendict()
+            skip_pars = ['variant_map', 'vaccine_map'] # These include non-string keys so fail at sc.flattendict()
 
         # Export results
         result_df = self.to_df(date_index=True)
@@ -620,16 +632,20 @@ class BaseSim(ParsObj):
 
     def shrink(self, skip_attrs=None, in_place=True):
         '''
-        "Shrinks" the simulation by removing the people, and returns
-        a copy of the "shrunken" simulation. Used to reduce the memory required
+        "Shrinks" the simulation by removing the people and other memory-intensive
+        attributes (e.g., some interventions and analyzers), and returns a copy of
+        the "shrunken" simulation. Used to reduce the memory required for RAM or
         for saved files.
 
         Args:
-            skip_attrs (list): a list of attributes to skip in order to perform the shrinking; default "people"
+            skip_attrs (list): a list of attributes to skip (remove) in order to perform the shrinking; default "people"
+            in_palce (bool): whether to perform the shrinking in place (default), or return a shrunken copy instead
 
         Returns:
-            shrunken_sim (Sim): a Sim object with the listed attributes removed
+            shrunken (Sim): a Sim object with the listed attributes removed
         '''
+        from . import interventions as cvi # To avoid circular imports
+        from . import analysis as cva
 
         # By default, skip people (~90% of memory), the popdict (which is usually empty anyway), and _orig_pars (which is just a backup)
         if skip_attrs is None:
@@ -637,13 +653,24 @@ class BaseSim(ParsObj):
 
         # Create the new object, and copy original dict, skipping the skipped attributes
         if in_place:
+            shrunken = self
             for attr in skip_attrs:
                 setattr(self, attr, None)
+        else:
+            shrunken = object.__new__(self.__class__)
+            shrunken.__dict__ = {k:(v if k not in skip_attrs else None) for k,v in self.__dict__.items()}
+
+        # Shrink interventions and analyzers, with a lot of checking along the way
+        for key in ['interventions', 'analyzers']:
+            ias = self.pars[key] # List of interventions or analyzers
+            shrunken_ias = [ia.shrink(in_place=in_place) for ia in ias if isinstance(ia, (cvi.Intervention, cva.Analyzer))]
+            self.pars[key] = shrunken_ias # Actually shrink, and re-store
+
+        # Don't return if in place
+        if in_place:
             return
         else:
-            shrunken_sim = object.__new__(self.__class__)
-            shrunken_sim.__dict__ = {k:(v if k not in skip_attrs else None) for k,v in self.__dict__.items()}
-            return shrunken_sim
+            return shrunken
 
 
     def save(self, filename=None, keep_people=None, skip_attrs=None, **kwargs):
@@ -659,7 +686,7 @@ class BaseSim(ParsObj):
 
         **Example**::
 
-            sim.save() # Saves to a .sim file with the date and time of creation by default
+            sim.save() # Saves to a .sim file
         '''
 
         # Set keep_people based on whether or not we're in the middle of a run
@@ -716,7 +743,7 @@ class BaseSim(ParsObj):
             errormsg = f'This method is only defined for interventions and analyzers, not "{which}"'
             raise ValueError(errormsg)
 
-        ia_list = self.pars[which] # List of interventions or analyzers
+        ia_list = sc.tolist(self.pars[which]) # List of interventions or analyzers
         n_ia = len(ia_list) # Number of interventions/analyzers
 
         if label == 'summary': # Print a summary of the interventions
@@ -848,11 +875,133 @@ class BasePeople(FlexPretty):
     whereas this class exists to handle the less interesting implementation details.
     '''
 
+    def set_pars(self, pars=None):
+        '''
+        Re-link the parameters stored in the people object to the sim containing it,
+        and perform some basic validation.
+        '''
+        orig_pars = self.__dict__.get('pars') # Get the current parameters using dict's get method
+        if pars is None:
+            if orig_pars is not None: # If it has existing parameters, use them
+                pars = orig_pars
+            else:
+                pars = {}
+        elif sc.isnumber(pars): # Interpret as a population size
+            pars = {'pop_size':pars} # Ensure it's a dictionary
+
+        # Copy from old parameters to new parameters
+        if isinstance(orig_pars, dict):
+            for k,v in orig_pars.items():
+                if k not in pars:
+                    pars[k] = v
+
+        # Do minimal validation -- needed here since pop_size should be converted to an int when first set
+        if 'pop_size' not in pars:
+            errormsg = f'The parameter "pop_size" must be included in a population; keys supplied were:\n{sc.newlinejoin(pars.keys())}'
+            raise sc.KeyNotFoundError(errormsg)
+        pars['pop_size'] = int(pars['pop_size'])
+        pars.setdefault('n_variants', 1)
+        pars.setdefault('location', None)
+        self.pars = pars # Actually store the pars
+        return
+
+
+    def validate(self, sim_pars=None, die=True, verbose=False):
+        '''
+        Perform validation on the People object.
+
+        Args:
+            sim_pars (dict): dictionary of parameters from the sim to ensure they match the current People object
+            die (bool): whether to raise an exception if validation fails
+            verbose (bool): detail to print
+        '''
+
+        # Check that parameters match
+        if sim_pars is not None:
+            mismatches = {}
+            keys = ['pop_size', 'pop_type', 'location', 'pop_infected', 'frac_susceptible', 'n_variants'] # These are the keys used in generating the population
+            for key in keys:
+                sim_v = sim_pars.get(key)
+                ppl_v = self.pars.get(key)
+                if sim_v is not None and ppl_v is not None:
+                    if sim_v != ppl_v:
+                        mismatches[key] = sc.objdict(sim=sim_v, people=ppl_v)
+            if len(mismatches):
+                errormsg = 'Validation failed due to the following mismatches between the sim and the people parameters:\n'
+                for k,v in mismatches.items():
+                    errormsg += f'  {k}: sim={v.sim}, people={v.people}'
+                raise ValueError(errormsg)
+
+        # Check that the keys match
+        contact_layer_keys = set(self.contacts.keys())
+        layer_keys    = set(self.layer_keys())
+        if contact_layer_keys != layer_keys:
+            errormsg = f'Parameters layers {layer_keys} are not consistent with contact layers {contact_layer_keys}'
+            raise ValueError(errormsg)
+
+        # Check that the length of each array is consistent
+        expected_len = len(self)
+        expected_variants = self.pars['n_variants']
+        for key in self.keys():
+            if self[key].ndim == 1:
+                actual_len = len(self[key])
+            else: # If it's 2D, variants need to be checked separately
+                actual_variants, actual_len = self[key].shape
+                if actual_variants != expected_variants:
+                    if verbose:
+                        print(f'Resizing "{key}" from {actual_variants} to {expected_variants}')
+                    self._resize_arrays(keys=key, new_size=(expected_variants, expected_len))
+            if actual_len != expected_len: # pragma: no cover
+                if die:
+                    errormsg = f'Length of key "{key}" did not match population size ({actual_len} vs. {expected_len})'
+                    raise IndexError(errormsg)
+                else:
+                    if verbose:
+                        print(f'Resizing "{key}" from {actual_len} to {expected_len}')
+                    self._resize_arrays(keys=key)
+
+        # Check that the layers are valid
+        for layer in self.contacts.values():
+            layer.validate()
+
+        return
+
+
+    def _resize_arrays(self, new_size=None, keys=None):
+        ''' Resize arrays if any mismatches are found '''
+
+        # Handle None or tuple input (representing variants and pop_size)
+        if new_size is None:
+            new_size = len(self)
+        pop_size = new_size if not isinstance(new_size, tuple) else new_size[1]
+        self.pars['pop_size'] = pop_size
+
+        # Reset sizes
+        if keys is None:
+            keys = self.keys()
+        keys = sc.promotetolist(keys)
+        for key in keys:
+            self[key].resize(new_size, refcheck=False) # Don't worry about cross-references to the arrays
+
+        return
+
+
+    def lock(self):
+        ''' Lock the people object to prevent keys from being added '''
+        self._lock = True
+        return
+
+
+    def unlock(self):
+        ''' Unlock the people object to allow keys to be added '''
+        self._lock = False
+        return
+
+
     def __getitem__(self, key):
         ''' Allow people['attr'] instead of getattr(people, 'attr')
             If the key is an integer, alias `people.person()` to return a `Person` instance
         '''
-
         try:
             return self.__dict__[key]
         except: # pragma: no cover
@@ -872,18 +1021,6 @@ class BasePeople(FlexPretty):
         return
 
 
-    def lock(self):
-        ''' Lock the people object to prevent keys from being added '''
-        self._lock = True
-        return
-
-
-    def unlock(self):
-        ''' Unlock the people object to allow keys to be added '''
-        self._lock = False
-        return
-
-
     def __len__(self):
         ''' This is just a scalar, but validate() and _resize_arrays() make sure it's right '''
         return int(self.pars['pop_size'])
@@ -989,37 +1126,17 @@ class BasePeople(FlexPretty):
 
     def count(self, key):
         ''' Count the number of people for a given key '''
-        return (self[key]>0).sum()
+        return np.count_nonzero(self[key])
 
-    def count_by_strain(self, key, strain):
+
+    def count_by_variant(self, key, variant):
         ''' Count the number of people for a given key '''
-        return (self[key][strain,:]>0).sum()
+        return np.count_nonzero(self[key][variant,:])
 
 
     def count_not(self, key):
         ''' Count the number of people who do not have a property for a given key '''
-        return (self[key]==0).sum()
-
-
-    def set_pars(self, pars=None):
-        '''
-        Re-link the parameters stored in the people object to the sim containing it,
-        and perform some basic validation.
-        '''
-        if pars is None:
-            pars = {}
-        elif sc.isnumber(pars): # Interpret as a population size
-            pars = {'pop_size':pars} # Ensure it's a dictionary
-        orig_pars = self.__dict__.get('pars') # Get the current parameters using dict's get method
-        pars = sc.mergedicts(orig_pars, pars)
-        if 'pop_size' not in pars:
-            errormsg = f'The parameter "pop_size" must be included in a population; keys supplied were:\n{sc.newlinejoin(pars.keys())}'
-            raise sc.KeyNotFoundError(errormsg)
-        pars['pop_size'] = int(pars['pop_size'])
-        pars.setdefault('n_strains', 1)
-        pars.setdefault('location', None)
-        self.pars = pars # Actually store the pars
-        return
+        return len(self[key]) - self.count(key)
 
 
     def keys(self):
@@ -1064,62 +1181,6 @@ class BasePeople(FlexPretty):
         return np.arange(len(self))
 
 
-    def validate(self, die=True, verbose=False):
-
-        # Check that the keys match
-        contact_layer_keys = set(self.contacts.keys())
-        layer_keys    = set(self.layer_keys())
-        if contact_layer_keys != layer_keys:
-            errormsg = f'Parameters layers {layer_keys} are not consistent with contact layers {contact_layer_keys}'
-            raise ValueError(errormsg)
-
-        # Check that the length of each array is consistent
-        expected_len = len(self)
-        expected_strains = self.pars['n_strains']
-        for key in self.keys():
-            if self[key].ndim == 1:
-                actual_len = len(self[key])
-            else: # If it's 2D, strains need to be checked separately
-                actual_strains, actual_len = self[key].shape
-                if actual_strains != expected_strains:
-                    if verbose:
-                        print(f'Resizing "{key}" from {actual_strains} to {expected_strains}')
-                    self._resize_arrays(keys=key, new_size=(expected_strains, expected_len))
-            if actual_len != expected_len: # pragma: no cover
-                if die:
-                    errormsg = f'Length of key "{key}" did not match population size ({actual_len} vs. {expected_len})'
-                    raise IndexError(errormsg)
-                else:
-                    if verbose:
-                        print(f'Resizing "{key}" from {actual_len} to {expected_len}')
-                    self._resize_arrays(keys=key)
-
-        # Check that the layers are valid
-        for layer in self.contacts.values():
-            layer.validate()
-
-        return
-
-
-    def _resize_arrays(self, new_size=None, keys=None):
-        ''' Resize arrays if any mismatches are found '''
-
-        # Handle None or tuple input (representing strains and pop_size)
-        if new_size is None:
-            new_size = len(self)
-        pop_size = new_size if not isinstance(new_size, tuple) else new_size[1]
-        self.pars['pop_size'] = pop_size
-
-        # Reset sizes
-        if keys is None:
-            keys = self.keys()
-        keys = sc.promotetolist(keys)
-        for key in keys:
-            self[key].resize(new_size, refcheck=False) # Don't worry about cross-references to the arrays
-
-        return
-
-
     def to_df(self):
         ''' Convert to a Pandas dataframe '''
         df = pd.DataFrame.from_dict({key:self[key] for key in self.keys()})
@@ -1159,12 +1220,12 @@ class BasePeople(FlexPretty):
         return p
 
 
-    def to_people(self):
+    def to_list(self):
         ''' Return all people as a list '''
         return list(self)
 
 
-    def from_people(self, people, resize=True):
+    def from_list(self, people, resize=True):
         ''' Convert a list of people back into a People object '''
 
         # Handle population size
@@ -1215,6 +1276,78 @@ class BasePeople(FlexPretty):
         return G
 
 
+    def save(self, filename=None, force=False, **kwargs):
+        '''
+        Save to disk as a gzipped pickle.
+
+        Note: by default this function raises an exception if trying to save a
+        run or partially run People object, since the changes that happen during
+        a run are usually irreversible.
+
+        Args:
+            filename (str or None): the name or path of the file to save to; if None, uses stored
+            force (bool): whether to allow saving even of a run or partially-run People object
+            kwargs: passed to ``sc.makefilepath()``
+
+        Returns:
+            filename (str): the validated absolute path to the saved file
+
+        **Example**::
+
+            sim = cv.Sim()
+            sim.initialize()
+            sim.people.save() # Saves to a .ppl file
+        '''
+
+        # Check if we're trying to save an already run People object
+        if self.t > 0 and not force:
+            errormsg = f'''
+The People object has already been run (t = {self.t}), which is usually not the
+correct state to save it in since it cannot be re-initialized. If this is intentional,
+use sim.people.save(force=True). Otherwise, the correct approach is:
+
+    sim = cv.Sim(...)
+    sim.initialize() # Create the people object but do not run
+    sim.people.save() # Save people immediately after initialization
+    sim.run() # The People object is
+'''
+            raise RuntimeError(errormsg)
+
+        # Handle the filename
+        if filename is None:
+            filename = 'covasim.ppl'
+        filename = sc.makefilepath(filename=filename, **kwargs)
+        self.filename = filename # Store the actual saved filename
+        cvm.save(filename=filename, obj=self)
+
+        return filename
+
+
+    @staticmethod
+    def load(filename, *args, **kwargs):
+        '''
+        Load from disk from a gzipped pickle.
+
+        Args:
+            filename (str): the name or path of the file to load from
+            args (list): passed to ``cv.load()``
+            kwargs (dict): passed to ``cv.load()``
+
+        Returns:
+            people (People): the loaded people object
+
+        **Example**::
+
+            people = cv.people.load('my-people.ppl')
+        '''
+        people = cvm.load(filename, *args, **kwargs)
+        if not isinstance(people, BasePeople): # pragma: no cover
+            errormsg = f'Cannot load object of {type(people)} as a People object'
+            raise TypeError(errormsg)
+        return people
+
+
+
     def init_contacts(self, reset=False):
         ''' Initialize the contacts dataframe with the correct columns and data types '''
 
@@ -1234,22 +1367,21 @@ class BasePeople(FlexPretty):
         Add new contacts to the array. See also contacts.add_layer().
         '''
 
-        # If no layer key is supplied and it can't be worked out from defaults, use the first layer
-        if lkey is None:
-            lkey = self.layer_keys()[0]
-
         # Validate the supplied contacts
-        if isinstance(contacts, Contacts):
-            new_contacts = contacts
+        if isinstance(contacts, (Contacts, dict)): # If it's a Contacts object or a dict, we can use it directly
+            if isinstance(contacts, dict) and lkey is not None: # Edge case: a dict for a single layer has been provided
+                new_contacts = {}
+                new_contacts[lkey] = contacts
+            else:
+                if 'p1' in contacts: # Avoid the mistake of passing a single layer
+                    errormsg = 'To supply a single layer as a dict, you must supply an lkey as well'
+                    raise ValueError(errormsg)
+                new_contacts = contacts # Main use case
         elif isinstance(contacts, Layer):
+            if lkey is None: # If no layer key is supplied, use the first layer
+                lkey = self.layer_keys()[0]
             new_contacts = {}
             new_contacts[lkey] = contacts
-        elif sc.checktype(contacts, 'array'):
-            new_contacts = {}
-            new_contacts[lkey] = pd.DataFrame(data=contacts)
-        elif isinstance(contacts, dict):
-            new_contacts = {}
-            new_contacts[lkey] = pd.DataFrame.from_dict(contacts)
         elif isinstance(contacts, list): # Assume it's a list of contacts by person, not an edgelist
             new_contacts = self.make_edgelist(contacts) # Assume contains key info
         else: # pragma: no cover
@@ -1371,11 +1503,22 @@ class FlexDict(dict):
 class Contacts(FlexDict):
     '''
     A simple (for now) class for storing different contact layers.
+
+    Args:
+        data (dict): a dictionary that looks like a Contacts object
+        layer_keys (list): if provided, create an empty Contacts object with these layers
+        kwargs (dict): additional layer(s), merged with data
+
+    New in version 3.1.2: swapped order of arguments
     '''
-    def __init__(self, layer_keys=None):
+    def __init__(self, data=None, layer_keys=None, **kwargs):
+        data = sc.mergedicts(data, kwargs)
         if layer_keys is not None:
             for lkey in layer_keys:
                 self[lkey] = Layer(label=lkey)
+        if data:
+            for lkey,layer_data in data.items():
+                self[lkey] = Layer(**layer_data)
         return
 
     def __repr__(self):
@@ -1410,6 +1553,13 @@ class Contacts(FlexDict):
             sim.people.contacts.add_layer(hospitals=hospitals_layer)
         '''
         for lkey,layer in kwargs.items():
+            if not isinstance(layer, Layer):
+                try:
+                    layer = Layer(layer, label=lkey)
+                except Exception as E:
+                    exc = type(E)
+                    errormsg = f'Could not parse {type(layer)} as layer: must be Layer or dict'
+                    raise exc(errormsg) from E
             layer.validate()
             self[lkey] = layer
         return
@@ -1482,14 +1632,17 @@ class Layer(FlexDict):
         p2 = np.random.randint(n_people, size=n)
         beta = np.ones(n)
         layer = cv.Layer(p1=p1, p2=p2, beta=beta, label='rand')
+        layer = cv.Layer(dict(p1=p1, p2=p2, beta=beta), label='rand') # Alternate method
 
         # Convert one layer to another with extra columns
         index = np.arange(n)
         self_conn = p1 == p2
         layer2 = cv.Layer(**layer, index=index, self_conn=self_conn, label=layer.label)
+
+    New in version 3.1.2: allow a single dictionary input
     '''
 
-    def __init__(self, label=None, **kwargs):
+    def __init__(self, *args, label=None, **kwargs):
         self.meta = {
             'p1':    cvd.default_int,   # Person 1
             'p2':    cvd.default_int,   # Person 2
@@ -1498,6 +1651,9 @@ class Layer(FlexDict):
         self.basekey = 'p1' # Assign a base key for calculating lengths and performing other operations
         self.label = label
 
+        # Handle args
+        kwargs = sc.mergedicts(*args, kwargs)
+
         # Initialize the keys of the layers
         for key,dtype in self.meta.items():
             self[key] = np.empty((0,), dtype=dtype)
@@ -1506,6 +1662,11 @@ class Layer(FlexDict):
         for key,value in kwargs.items():
             self[key] = np.array(value, dtype=self.meta.get(key))
 
+        # Set beta if not provided
+        key = 'beta'
+        if key not in kwargs.keys():
+            self[key] = np.ones(len(self), dtype=self.meta[key])
+
         return
 
 
@@ -1551,19 +1712,23 @@ class Layer(FlexDict):
         return self.meta.keys()
 
 
-    def validate(self):
-        ''' Check the integrity of the layer: right types, right lengths '''
+    def validate(self, force=True):
+        '''
+        Check the integrity of the layer: right types, right lengths.
+
+        If dtype is incorrect, try to convert automatically; if length is incorrect,
+        do not.
+        '''
         n = len(self[self.basekey])
         for key,dtype in self.meta.items():
             if dtype:
                 actual = self[key].dtype
                 expected = dtype
                 if actual != expected:
-                    errormsg = f'Expecting dtype "{expected}" for layer key "{key}"; got "{actual}"'
-                    raise TypeError(errormsg)
+                    self[key] = np.array(self[key], dtype=expected) # Probably harmless, so try to convert to correct type
             actual_n = len(self[key])
             if n != actual_n:
-                errormsg = f'Expecting length {n} for layer key "{key}"; got {actual_n}'
+                errormsg = f'Expecting length {n} for layer key "{key}"; got {actual_n}' # We can't fix length mismatches
                 raise TypeError(errormsg)
         return
 
@@ -1679,7 +1844,7 @@ class Layer(FlexDict):
         '''
         Regenerate contacts on each timestep.
 
-        This method gets called if the layer appears in ``sim.pars['dynam_lkeys']``.
+        This method gets called if the layer appears in ``sim.pars['dynam_layer']``.
         The Layer implements the update procedure so that derived classes can customize
         the update e.g. implementing over-dispersion/other distributions, random
         clusters, etc.
@@ -1689,6 +1854,7 @@ class Layer(FlexDict):
         changing contacts for people that are severe/critical).
 
         Args:
+            people (People): the Covasim People object, which is usually used to make new contacts
             frac (float): the fraction of contacts to update on each timestep
         '''
         # Choose how many contacts to make
