@@ -8,7 +8,8 @@ from .settings import options as cvo # For setting global options
 from . import misc as cvm
 from . import defaults as cvd
 
-__all__ = ['make_pars', 'reset_layer_pars', 'get_prognoses', 'get_strain_choices', 'get_vaccine_choices']
+__all__ = ['make_pars', 'reset_layer_pars', 'get_prognoses', 'get_variant_choices', 'get_vaccine_choices',
+           'get_variant_pars', 'get_cross_immunity', 'get_vaccine_variant_pars', 'get_vaccine_dose_pars']
 
 
 def make_pars(set_prognoses=False, prog_by_age=True, version=None, **kwargs):
@@ -56,28 +57,28 @@ def make_pars(set_prognoses=False, prog_by_age=True, version=None, **kwargs):
     pars['beta_layer']      = None  # Transmissibility per layer; set by reset_layer_pars() below
 
     # Basic disease transmission parameters
-    pars['beta_dist']       = dict(dist='neg_binomial', par1=1.0, par2=0.45, step=0.01) # Distribution to draw individual level transmissibility; dispersion from https://www.researchsquare.com/article/rs-29548/v1
-    pars['viral_dist']      = dict(frac_time=0.3, load_ratio=2, high_cap=4) # The time varying viral load (transmissibility); estimated from Lescure 2020, Lancet, https://doi.org/10.1016/S1473-3099(20)30200-0
-    pars['beta'] = 0.016  # Beta per symptomatic contact; absolute value, calibrated
-    pars['asymp_factor']    = 1.0  # Multiply beta by this factor for asymptomatic cases; no statistically significant difference in transmissibility: https://www.sciencedirect.com/science/article/pii/S1201971220302502
+    pars['beta_dist']    = dict(dist='neg_binomial', par1=1.0, par2=0.45, step=0.01) # Distribution to draw individual level transmissibility; dispersion from https://www.researchsquare.com/article/rs-29548/v1
+    pars['viral_dist']   = dict(frac_time=0.3, load_ratio=2, high_cap=4) # The time varying viral load (transmissibility); estimated from Lescure 2020, Lancet, https://doi.org/10.1016/S1473-3099(20)30200-0
+    pars['beta']         = 0.016  # Beta per symptomatic contact; absolute value, calibrated
+    pars['asymp_factor'] = 1.0  # Multiply beta by this factor for asymptomatic cases; no statistically significant difference in transmissibility: https://www.sciencedirect.com/science/article/pii/S1201971220302502
 
-    # Parameters that control settings and defaults for multi-strain runs
-    pars['n_imports'] = 0 # Average daily number of imported cases (actual number is drawn from Poisson distribution)
-    pars['n_strains'] = 1 # The number of strains circulating in the population
+    # Parameters that control settings and defaults for multi-variant runs
+    pars['n_imports']  = 0 # Average daily number of imported cases (actual number is drawn from Poisson distribution)
+    pars['n_variants'] = 1 # The number of variants circulating in the population
 
     # Parameters used to calculate immunity
-    pars['use_waning']      = False # Whether to use dynamically calculated immunity
-    pars['nab_init']        = dict(dist='normal', par1=0, par2=2)  # Parameters for the distribution of the initial level of log2(nab) following natural infection, taken from fig1b of https://doi.org/10.1101/2021.03.09.21252641
-    pars['nab_decay']       = dict(form='nab_decay', decay_rate1=np.log(2)/90, decay_time1=250, decay_rate2=0.001) # Parameters describing the kinetics of decay of nabs over time, taken from fig3b of https://doi.org/10.1101/2021.03.09.21252641
-    pars['nab_kin']         = None # Constructed during sim initialization using the nab_decay parameters
-    pars['nab_boost']       = 1.5 # Multiplicative factor applied to a person's nab levels if they get reinfected. # TODO: add source
-    pars['nab_eff']         = dict(sus=dict(slope=1.6, n_50=0.05), symp=0.1, sev=0.52) # Parameters to map nabs to efficacy
-    pars['rel_imm_symp']    = dict(asymp=0.85, mild=1, severe=1.5) # Relative immunity from natural infection varies by symptoms
-    pars['immunity']        = None  # Matrix of immunity and cross-immunity factors, set by init_immunity() in immunity.py
+    pars['use_waning']   = True # Whether to use dynamically calculated immunity
+    pars['nab_init']     = dict(dist='normal', par1=0, par2=2)  # Parameters for the distribution of the initial level of log2(nab) following natural infection, taken from fig1b of https://doi.org/10.1101/2021.03.09.21252641
+    pars['nab_decay']    = dict(form='nab_growth_decay', growth_time=21, decay_rate1=np.log(2) / 50, decay_time1=150, decay_rate2=np.log(2) / 250, decay_time2=365)
+    pars['nab_kin']      = None # Constructed during sim initialization using the nab_decay parameters
+    pars['nab_boost']    = 1.5 # Multiplicative factor applied to a person's nab levels if they get reinfected. No data on this, assumption.
+    pars['nab_eff']      = dict(alpha_inf=1.08, alpha_inf_diff=1.812, beta_inf=0.967, alpha_symp_inf=-0.739, beta_symp_inf=0.038, alpha_sev_symp=-0.014, beta_sev_symp=0.079) # Parameters to map nabs to efficacy
+    pars['rel_imm_symp'] = dict(asymp=0.85, mild=1, severe=1.5) # Relative immunity from natural infection varies by symptoms. Assumption.
+    pars['immunity']     = None  # Matrix of immunity and cross-immunity factors, set by init_immunity() in immunity.py
+    pars['trans_redux']  = 0.59  # Reduction in transmission for breakthrough infections, https://www.medrxiv.org/content/10.1101/2021.07.13.21260393v
 
-    # Strain-specific disease transmission parameters. By default, these are set up for a single strain, but can all be modified for multiple strains
-    pars['rel_beta']        = 1.0 # Relative transmissibility varies by strain
-    pars['rel_imm_strain']  = 1.0 # Relative own-immmunity varies by strain
+    # Variant-specific disease transmission parameters. By default, these are set up for a single variant, but can all be modified for multiple variants
+    pars['rel_beta']        = 1.0 # Relative transmissibility varies by variant
 
     # Duration parameters: time for disease progression
     pars['dur'] = {}
@@ -118,15 +119,15 @@ def make_pars(set_prognoses=False, prog_by_age=True, version=None, **kwargs):
     pars['no_hosp_factor'] = 2.0  # Multiplier for how much more likely severely ill people are to become critical if no hospital beds are available
     pars['no_icu_factor']  = 2.0  # Multiplier for how much more likely critically ill people are to die if no ICU beds are available
 
-    # Handle vaccine and strain parameters
+    # Handle vaccine and variant parameters
     pars['vaccine_pars'] = {} # Vaccines that are being used; populated during initialization
     pars['vaccine_map']  = {} #Reverse mapping from number to vaccine key
-    pars['strains']      = [] # Additional strains of the virus; populated by the user, see immunity.py
-    pars['strain_map']   = {0:'wild'} # Reverse mapping from number to strain key
-    pars['strain_pars']  = dict(wild={}) # Populated just below
-    for sp in cvd.strain_pars:
+    pars['variants']     = [] # Additional variants of the virus; populated by the user, see immunity.py
+    pars['variant_map']  = {0:'wild'} # Reverse mapping from number to variant key
+    pars['variant_pars'] = dict(wild={}) # Populated just below
+    for sp in cvd.variant_pars:
         if sp in pars.keys():
-            pars['strain_pars']['wild'][sp] = pars[sp]
+            pars['variant_pars']['wild'][sp] = pars[sp]
 
     # Update with any supplied parameter values and generate things that need to be generated
     pars.update(kwargs)
@@ -137,12 +138,14 @@ def make_pars(set_prognoses=False, prog_by_age=True, version=None, **kwargs):
     # If version is specified, load old parameters
     if version is not None:
         version_pars = cvm.get_version_pars(version, verbose=pars['verbose'])
+        if sc.compareversions(version, '<3.0.0'): # Waning was introduced in 3.0, so is always false before
+            version_pars['use_waning'] = False
         for key in pars.keys(): # Only loop over keys that have been populated
             if key in version_pars: # Only replace keys that exist in the old version
                 pars[key] = version_pars[key]
 
         # Handle code change migration
-        if sc.compareversions(version, '2.1.0') == -1 and 'migrate_lognormal' not in pars:
+        if sc.compareversions(version, '<2.1.0') and 'migrate_lognormal' not in pars:
             cvm.migrate_lognormal(pars, verbose=pars['verbose'])
 
     return pars
@@ -186,12 +189,7 @@ def reset_layer_pars(pars, layer_keys=None, force=False):
     )
 
     # Specify defaults for SynthPops -- same as hybrid except for LTCF layer (l)
-    l_pars = dict(beta_layer=1.5,
-                  contacts=10,
-                  dynam_layer=0,
-                  iso_factor=0.2,
-                  quar_factor=0.3
-    )
+    l_pars = dict(beta_layer=1.5, contacts=10, dynam_layer=0, iso_factor=0.2, quar_factor=0.3)
     layer_defaults['synthpops'] = sc.dcp(layer_defaults['hybrid'])
     for key,val in l_pars.items():
         layer_defaults['synthpops'][key]['l'] = val
@@ -244,11 +242,14 @@ def get_prognoses(by_age=True, version=None):
 
     if not by_age: # All rough estimates -- almost always, prognoses by age (below) are used instead
         prognoses = dict(
-            age_cutoffs  = np.array([0]),
-            symp_probs   = np.array([0.75]),
-            severe_probs = np.array([0.10]),
-            crit_probs   = np.array([0.04]),
-            death_probs  = np.array([0.01]),
+            age_cutoffs   = np.array([0]),
+            sus_ORs       = np.array([1.00]),
+            trans_ORs     = np.array([1.00]),
+            symp_probs    = np.array([0.75]),
+            comorbidities = np.array([1.00]),
+            severe_probs  = np.array([0.10]),
+            crit_probs    = np.array([0.04]),
+            death_probs   = np.array([0.01]),
         )
     else:
         prognoses = dict(
@@ -264,7 +265,7 @@ def get_prognoses(by_age=True, version=None):
     prognoses = relative_prognoses(prognoses) # Convert to conditional probabilities
 
     # If version is specified, load old parameters
-    if version is not None:
+    if by_age and version is not None:
         version_prognoses = cvm.get_version_pars(version, verbose=False)['prognoses']
         for key in version_prognoses.keys(): # Only loop over keys that have been populated
             if key in version_prognoses: # Only replace keys that exist in the old version
@@ -311,18 +312,19 @@ def absolute_prognoses(prognoses):
     return out
 
 
-#%% Strain, vaccine, and immunity parameters and functions
+#%% Variant, vaccine, and immunity parameters and functions
 
-def get_strain_choices():
+def get_variant_choices():
     '''
-    Define valid pre-defined strain names
+    Define valid pre-defined variant names
     '''
     # List of choices currently available: new ones can be added to the list along with their aliases
     choices = {
         'wild':  ['wild', 'default', 'pre-existing', 'original'],
-        'b117':  ['b117', 'uk', 'united kingdom'],
-        'b1351': ['b1351', 'sa', 'south africa'],
-        'p1':    ['p1', 'b11248', 'brazil'],
+        'alpha': ['alpha', 'b117', 'uk', 'united kingdom', 'kent'],
+        'beta':  ['beta', 'b1351', 'sa', 'south africa'],
+        'gamma': ['gamma', 'p1', 'b11248', 'brazil'],
+        'delta': ['delta', 'b16172', 'india'],
     }
     mapping = {name:key for key,synonyms in choices.items() for name in synonyms} # Flip from key:value to value:key
     return choices, mapping
@@ -335,24 +337,45 @@ def get_vaccine_choices():
     # List of choices currently available: new ones can be added to the list along with their aliases
     choices = {
         'default': ['default', None],
-        'pfizer':  ['pfizer', 'biontech', 'pfizer-biontech', 'pf', 'pfz', 'pz'],
-        'moderna': ['moderna', 'md'],
+        'pfizer':  ['pfizer', 'biontech', 'pfizer-biontech', 'pf', 'pfz', 'pz', 'bnt162b2', 'comirnaty'],
+        'moderna': ['moderna', 'md', 'spikevax'],
         'novavax': ['novavax', 'nova', 'covovax', 'nvx', 'nv'],
-        'az':      ['astrazeneca', 'oxford', 'vaxzevria', 'az'],
+        'az':      ['astrazeneca', 'az', 'covishield', 'oxford', 'vaxzevria'],
         'jj':      ['jnj', 'johnson & johnson', 'janssen', 'jj'],
+        'sinovac': ['sinovac', 'coronavac'],
+        'sinopharm': ['sinopharm']
     }
     mapping = {name:key for key,synonyms in choices.items() for name in synonyms} # Flip from key:value to value:key
     return choices, mapping
 
 
-def get_strain_pars(default=False):
+def _get_from_pars(pars, default=False, key=None, defaultkey='default'):
+    ''' Helper function to get the right output from vaccine and variant functions '''
+
+    # If a string was provided, interpret it as a key and swap
+    if isinstance(default, str):
+        key, default = default, key
+
+    # Handle output
+    if key is not None:
+        try:
+            return pars[key]
+        except Exception as E:
+            errormsg = f'Key "{key}" not found; choices are: {sc.strjoin(pars.keys())}'
+            raise sc.KeyNotFoundError(errormsg) from E
+    elif default:
+        return pars[defaultkey]
+    else:
+        return pars
+
+
+def get_variant_pars(default=False, variant=None):
     '''
-    Define the default parameters for the different strains
+    Define the default parameters for the different variants
     '''
     pars = dict(
 
         wild = dict(
-            rel_imm_strain  = 1.0, # Default values
             rel_beta        = 1.0, # Default values
             rel_symp_prob   = 1.0, # Default values
             rel_severe_prob = 1.0, # Default values
@@ -360,194 +383,228 @@ def get_strain_pars(default=False):
             rel_death_prob  = 1.0, # Default values
         ),
 
-        b117 = dict(
-            rel_imm_strain  = 1.0, # Immunity protection obtained from a natural infection with wild type, relative to wild type. No evidence yet for a difference with B117
-            rel_beta        = 1.5, # Transmissibility estimates range from 40-80%, see https://cmmid.github.io/topics/covid19/uk-novel-variant.html, https://www.eurosurveillance.org/content/10.2807/1560-7917.ES.2020.26.1.2002106
-            rel_symp_prob   = 1.0, # Inconclusive evidence on the likelihood of symptom development. See https://www.thelancet.com/journals/lanpub/article/PIIS2468-2667(21)00055-4/fulltext
-            rel_severe_prob = 1.8, # From https://www.ssi.dk/aktuelt/nyheder/2021/b117-kan-fore-til-flere-indlaggelser and https://assets.publishing.service.gov.uk/government/uploads/system/uploads/attachment_data/file/961042/S1095_NERVTAG_update_note_on_B.1.1.7_severity_20210211.pdf
-            rel_crit_prob   = 1.0, # Various studies have found increased mortality for B117 (summary here: https://www.thelancet.com/journals/laninf/article/PIIS1473-3099(21)00201-2/fulltext#tbl1), but not necessarily when conditioned on having developed severe disease
-            rel_death_prob  = 1.0, # See comment above.
+        alpha = dict(
+            rel_beta        = 1.67, # Midpoint of the range reported in https://science.sciencemag.org/content/372/6538/eabg3055
+            rel_symp_prob   = 1.0,  # Inconclusive evidence on the likelihood of symptom development. See https://www.thelancet.com/journals/lanpub/article/PIIS2468-2667(21)00055-4/fulltext
+            rel_severe_prob = 1.64, # From https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3792894, and consistent with https://www.eurosurveillance.org/content/10.2807/1560-7917.ES.2021.26.16.2100348 and https://assets.publishing.service.gov.uk/government/uploads/system/uploads/attachment_data/file/961042/S1095_NERVTAG_update_note_on_B.1.1.7_severity_20210211.pdf
+            rel_crit_prob   = 1.0,  # Various studies have found increased mortality for B117 (summary here: https://www.thelancet.com/journals/laninf/article/PIIS1473-3099(21)00201-2/fulltext#tbl1), but not necessarily when conditioned on having developed severe disease
+            rel_death_prob  = 1.0,  # See comment above
         ),
 
-        b1351 = dict(
-            rel_imm_strain  = 1.0, # Immunity protection obtained from a natural infection with wild type, relative to wild type. TODO: add source
-            rel_beta        = 1.4,
+        beta = dict(
+            rel_beta        = 1.0, # No increase in transmissibility; B1351's fitness advantage comes from the reduction in neutralisation
             rel_symp_prob   = 1.0,
-            rel_severe_prob = 1.4,
+            rel_severe_prob = 3.6, # From https://www.eurosurveillance.org/content/10.2807/1560-7917.ES.2021.26.16.2100348
             rel_crit_prob   = 1.0,
-            rel_death_prob  = 1.4,
+            rel_death_prob  = 1.0,
         ),
 
-        p1 = dict(
-            rel_imm_strain  = 0.17,
-            rel_beta        = 1.4, # Estimated to be 1.7–2.4-fold more transmissible than wild-type: https://science.sciencemag.org/content/early/2021/04/13/science.abh2644
+        gamma = dict(
+            rel_beta        = 2.05, # Estimated to be 1.7–2.4-fold more transmissible than wild-type: https://science.sciencemag.org/content/early/2021/04/13/science.abh2644
             rel_symp_prob   = 1.0,
-            rel_severe_prob = 1.4,
+            rel_severe_prob = 2.6, # From https://www.eurosurveillance.org/content/10.2807/1560-7917.ES.2021.26.16.2100348
             rel_crit_prob   = 1.0,
-            rel_death_prob  = 2.0,
+            rel_death_prob  = 1.0,
+        ),
+
+        delta = dict(
+            rel_beta        = 2.2, # Estimated to be 1.25-1.6-fold more transmissible than B117: https://www.researchsquare.com/article/rs-637724/v1
+            rel_symp_prob   = 1.0,
+            rel_severe_prob = 3.2, # 2x more transmissible than alpha from https://mobile.twitter.com/dgurdasani1/status/1403293582279294983
+            rel_crit_prob   = 1.0,
+            rel_death_prob  = 1.0,
         )
     )
 
-    if default:
-        return pars['wild']
-    else:
-        return pars
+    return _get_from_pars(pars, default, key=variant, defaultkey='wild')
 
 
-def get_cross_immunity(default=False):
+def get_cross_immunity(default=False, variant=None):
     '''
-    Get the cross immunity between each strain in a sim
+    Get the cross immunity between each variant in a sim
     '''
     pars = dict(
 
         wild = dict(
             wild  = 1.0, # Default for own-immunity
-            b117  = 0.5, # Assumption
-            b1351 = 0.5, # Assumption
-            p1    = 0.5, # Assumption
+            alpha = 0.5, # Assumption
+            beta  = 0.5, # https://www.nature.com/articles/s41586-021-03471-w
+            gamma = 0.34, # Assumption
+            delta = 0.374, # Assumption
         ),
 
-        b117 = dict(
+        alpha = dict(
             wild  = 0.5, # Assumption
-            b117  = 1.0, # Default for own-immunity
-            b1351 = 0.8, # Assumption
-            p1    = 0.8, # Assumption
+            alpha = 1.0, # Default for own-immunity
+            beta  = 0.8, # Assumption
+            gamma = 0.8, # Assumption
+            delta = 0.689  # Assumption
         ),
 
-        b1351 = dict(
+        beta = dict(
             wild  = 0.066, # https://www.nature.com/articles/s41586-021-03471-w
-            b117  = 0.5,   # Assumption
-            b1351 = 1.0,   # Default for own-immunity
-            p1    = 0.5,   # Assumption
+            alpha = 0.5,   # Assumption
+            beta  = 1.0,   # Default for own-immunity
+            gamma = 0.5,   # Assumption
+            delta = 0.086    # Assumption
         ),
 
-        p1 = dict(
+        gamma = dict(
             wild  = 0.34, # Previous (non-P.1) infection provides 54–79% of the protection against infection with P.1 that it provides against non-P.1 lineages: https://science.sciencemag.org/content/early/2021/04/13/science.abh2644
-            b117  = 0.4,  # Assumption based on the above
-            b1351 = 0.4,  # Assumption based on the above
-            p1    = 1.0,  # Default for own-immunity
+            alpha = 0.4,  # Assumption based on the above
+            beta  = 0.4,  # Assumption based on the above
+            gamma = 1.0,  # Default for own-immunity
+            delta = 0.088   # Assumption
+        ),
+
+        delta = dict( # Parameters from https://www.cell.com/cell/fulltext/S0092-8674(21)00755-8
+            wild  = 0.374,
+            alpha = 0.689,
+            beta  = 0.086,
+            gamma = 0.088,
+            delta = 1.0 # Default for own-immunity
         ),
     )
 
-    if default:
-        return pars['wild']
-    else:
-        return pars
+    return _get_from_pars(pars, default, key=variant, defaultkey='wild')
 
 
-def get_vaccine_strain_pars(default=False):
+def get_vaccine_variant_pars(default=False, vaccine=None):
     '''
-    Define the effectiveness of each vaccine against each strain
+    Define the effectiveness of each vaccine against each variant
     '''
     pars = dict(
 
         default = dict(
             wild  = 1.0,
-            b117  = 1.0,
-            b1351 = 1.0,
-            p1    = 1.0,
+            alpha = 1.0,
+            beta  = 1.0,
+            gamma = 1.0,
+            delta = 1.0,
         ),
 
         pfizer = dict(
             wild  = 1.0,
-            b117  = 1/2.0,
-            b1351 = 1/6.7,
-            p1    = 1/6.5,
+            alpha = 1/2.0, # https://www.nejm.org/doi/full/10.1056/nejmc2100362
+            beta  = 1/10.3, # https://www.nejm.org/doi/full/10.1056/nejmc2100362
+            gamma = 1/6.7, # https://www.nejm.org/doi/full/10.1056/nejmc2100362
+            delta = 1/2.9, # https://www.researchsquare.com/article/rs-637724/v1
         ),
 
         moderna = dict(
             wild  = 1.0,
-            b117  = 1/1.8,
-            b1351 = 1/4.5,
-            p1    = 1/8.6,
+            alpha = 1/1.8,
+            beta  = 1/4.5,
+            gamma = 1/8.6, # https://www.nejm.org/doi/full/10.1056/nejmc2100362
+            delta = 1/2.9,  # https://www.researchsquare.com/article/rs-637724/v1
         ),
 
         az = dict(
             wild  = 1.0,
-            b117  = 1/2.3,
-            b1351 = 1/9,
-            p1    = 1/2.9,
+            alpha = 1/2.3,
+            beta  = 1/9,
+            gamma = 1/2.9,
+            delta = 1/6.2,  # https://www.researchsquare.com/article/rs-637724/v1
         ),
 
         jj = dict(
             wild  = 1.0,
-            b117  = 1.0,
-            b1351 = 1/6.7,
-            p1    = 1/8.6,
+            alpha = 1.0,
+            beta  = 1/3.6,  # https://www.biorxiv.org/content/10.1101/2021.07.01.450707v1.full.pdf
+            gamma = 1/3.4,  # https://www.biorxiv.org/content/10.1101/2021.07.01.450707v1.full.pdf
+            delta = 1/1.6,  # https://www.biorxiv.org/content/10.1101/2021.07.01.450707v1.full.pdf
         ),
 
-        novavax = dict( # https://ir.novavax.com/news-releases/news-release-details/novavax-covid-19-vaccine-demonstrates-893-efficacy-uk-phase-3
+        novavax = dict( # Data from https://ir.novavax.com/news-releases/news-release-details/novavax-covid-19-vaccine-demonstrates-893-efficacy-uk-phase-3
             wild  = 1.0,
-            b117  = 1/1.12,
-            b1351 = 1/4.7,
-            p1    = 1/8.6, # assumption, no data available yet
+            alpha = 1/1.12,
+            beta  = 1/4.7,
+            gamma = 1/8.6, # Assumption, no data available yet
+            delta = 1/6.2, # Assumption, no data available yet
         ),
+
+        sinovac = dict(
+            wild  = 1.0,
+            alpha = 1/1.12,
+            beta  = 1/4.7,
+            gamma = 1/8.6, # Assumption, no data available yet
+            delta = 1/6.2, # Assumption, no data available yet
+        ),
+
+        sinopharm = dict(
+            wild  = 1.0,
+            alpha = 1/1.12,
+            beta  = 1/4.7,
+            gamma = 1/8.6, # Assumption, no data available yet
+            delta = 1/6.2, # Assumption, no data available yet
+        )
     )
 
-    if default:
-        return pars['default']
-    else:
-        return pars
+    return _get_from_pars(pars, default=default, key=vaccine)
 
 
-def get_vaccine_dose_pars(default=False):
+def get_vaccine_dose_pars(default=False, vaccine=None):
     '''
-    Define the dosing regimen for each vaccine
+    Define the parameters for each vaccine
     '''
+
     pars = dict(
 
         default = dict(
-            nab_eff   = dict(sus=dict(slope=1.6, n_50=0.05)),
-            nab_init  = dict(dist='normal', par1=2, par2=2),
-            nab_boost = 2,
-            doses     = 1,
-            interval  = None,
+            nab_init  = dict(dist='normal', par1=0, par2=2), # Initial distribution of NAbs
+            nab_boost = 2, # Factor by which a dose increases existing NABs
+            doses     = 1, # Number of doses for this vaccine
+            interval  = None, # Interval between doses
         ),
 
         pfizer = dict(
-            nab_eff   = dict(sus=dict(slope=1.6, n_50=0.05)),
-            nab_init  = dict(dist='normal', par1=2, par2=2),
-            nab_boost = 3,
+            nab_init  = dict(dist='normal', par1=-1, par2=2),
+            nab_boost = 4,
             doses     = 2,
             interval  = 21,
         ),
 
         moderna = dict(
-            nab_eff   = dict(sus=dict(slope=1.6, n_50=0.05)),
-            nab_init  = dict(dist='normal', par1=2, par2=2),
-            nab_boost = 3,
+            nab_init  = dict(dist='normal', par1=-1, par2=2),
+            nab_boost = 8,
             doses     = 2,
             interval  = 28,
         ),
 
         az = dict(
-            nab_eff   = dict(sus=dict(slope=1.6, n_50=0.05)),
-            nab_init  = dict(dist='normal', par1=-0.85, par2=2),
-            nab_boost = 3,
+            nab_init  = dict(dist='normal', par1=-1.5, par2=2),
+            nab_boost = 2,
             doses     = 2,
             interval  = 21,
         ),
 
         jj = dict(
-            nab_eff   = dict(sus=dict(slope=1.6, n_50=0.05)),
-            nab_init  = dict(dist='normal', par1=-1.1, par2=2),
+            nab_init  = dict(dist='normal', par1=1, par2=2),
             nab_boost = 3,
             doses     = 1,
             interval  = None,
         ),
 
         novavax = dict(
-            nab_eff   = dict(sus=dict(slope=1.6, n_50=0.05)),
             nab_init  = dict(dist='normal', par1=-0.9, par2=2),
             nab_boost = 3,
             doses     = 2,
             interval  = 21,
         ),
+
+        sinovac = dict(
+            nab_init  = dict(dist='normal', par1=-2, par2=2),
+            nab_boost = 2,
+            doses     = 2,
+            interval  = 14,
+        ),
+
+        sinopharm = dict(
+            nab_init  = dict(dist='normal', par1=-1, par2=2),
+            nab_boost = 2,
+            doses     = 2,
+            interval  = 21,
+        )
     )
 
-    if default:
-        return pars['default']
-    else:
-        return pars
-
-
+    return _get_from_pars(pars, default, key=vaccine)
\ No newline at end of file
