@@ -1,5 +1,6 @@
 '''
-Defines the Person class and functions associated with making people.
+Defines the People class and functions associated with making people and handling
+the transitions between states (e.g., from susceptible to infected).
 '''
 
 #%% Imports
@@ -18,22 +19,24 @@ __all__ = ['People']
 
 class People(cvb.BasePeople):
     '''
-    A class to perform all the operations on the people. This class is usually
-    not invoked directly, but instead is created automatically by the sim. The
-    only required input argument is the population size, but typically the full
-    parameters dictionary will get passed instead since it will be needed before
-    the People object is initialized.
+    A class to perform all the operations on the people -- usually not invoked directly.
+
+    This class is usually created automatically by the sim. The only required input
+    argument is the population size, but typically the full parameters dictionary
+    will get passed instead since it will be needed before the People object is
+    initialized. However, ages, contacts, etc. will need to be created separately --
+    see ``cv.make_people()`` instead.
 
     Note that this class handles the mechanics of updating the actual people, while
-    BasePeople takes care of housekeeping (saving, loading, exporting, etc.). Please
-    see the BasePeople class for additional methods.
+    ``cv.BasePeople`` takes care of housekeeping (saving, loading, exporting, etc.).
+    Please see the BasePeople class for additional methods.
 
     Args:
         pars (dict): the sim parameters, e.g. sim.pars -- alternatively, if a number, interpreted as pop_size
         strict (bool): whether or not to only create keys that are already in self.meta.person; otherwise, let any key be set
         kwargs (dict): the actual data, e.g. from a popdict, being specified
 
-    ::Examples::
+    **Examples**::
 
         ppl1 = cv.People(2000)
 
@@ -59,25 +62,28 @@ class People(cvb.BasePeople):
         for key in self.meta.person:
             if key == 'uid':
                 self[key] = np.arange(self.pars['pop_size'], dtype=cvd.default_int)
+            elif key in ['n_infections', 'n_breakthroughs']:
+                self[key] = np.zeros(self.pars['pop_size'], dtype=cvd.default_int)
             else:
                 self[key] = np.full(self.pars['pop_size'], np.nan, dtype=cvd.default_float)
 
-        # Set health states -- only susceptible is true by default -- booleans except exposed by strain which should return the strain that ind is exposed to
+        # Set health states -- only susceptible is true by default -- booleans except exposed by variant which should return the variant that ind is exposed to
         for key in self.meta.states:
             val = (key in ['susceptible', 'naive']) # Default value is True for susceptible and naive, false otherwise
             self[key] = np.full(self.pars['pop_size'], val, dtype=bool)
 
-        # Set strain states, which store info about which strain a person is exposed to
-        for key in self.meta.strain_states:
+        # Set variant states, which store info about which variant a person is exposed to
+        for key in self.meta.variant_states:
             self[key] = np.full(self.pars['pop_size'], np.nan, dtype=cvd.default_float)
-        for key in self.meta.by_strain_states:
-            self[key] = np.full((self.pars['n_strains'], self.pars['pop_size']), False, dtype=bool)
+        for key in self.meta.by_variant_states:
+            self[key] = np.full((self.pars['n_variants'], self.pars['pop_size']), False, dtype=bool)
 
         # Set immunity and antibody states
         for key in self.meta.imm_states:  # Everyone starts out with no immunity
-            self[key] = np.zeros((self.pars['n_strains'], self.pars['pop_size']), dtype=cvd.default_float)
+            self[key] = np.zeros((self.pars['n_variants'], self.pars['pop_size']), dtype=cvd.default_float)
         for key in self.meta.nab_states:  # Everyone starts out with no antibodies
-            self[key] = np.full(self.pars['pop_size'], np.nan, dtype=cvd.default_float)
+            dtype = cvd.default_int if key == 't_nab_event' else cvd.default_float
+            self[key] = np.zeros(self.pars['pop_size'], dtype=dtype)
         for key in self.meta.vacc_states:
             self[key] = np.zeros(self.pars['pop_size'], dtype=cvd.default_int)
 
@@ -115,16 +121,17 @@ class People(cvb.BasePeople):
     def init_flows(self):
         ''' Initialize flows to be zero '''
         self.flows = {key:0 for key in cvd.new_result_flows}
-        self.flows_strain = {}
-        for key in cvd.new_result_flows_by_strain:
-            self.flows_strain[key] = np.zeros(self.pars['n_strains'], dtype=cvd.default_float)
+        self.flows_variant = {}
+        for key in cvd.new_result_flows_by_variant:
+            self.flows_variant[key] = np.zeros(self.pars['n_variants'], dtype=cvd.default_float)
         return
 
 
-    def initialize(self):
+    def initialize(self, sim_pars=None):
         ''' Perform initializations '''
+        self.validate(sim_pars=sim_pars) # First, check that essential-to-match parameters match
+        self.set_pars(sim_pars) # Replace the saved parameters with this simulation's
         self.set_prognoses()
-        self.validate()
         self.initialized = True
         return
 
@@ -168,7 +175,7 @@ class People(cvb.BasePeople):
 
         # Initialize
         self.t = t
-        self.is_exp     = self.true('exposed') # For storing the interim values since used in every subsequent calculation
+        self.is_exp = self.true('exposed') # For storing the interim values since used in every subsequent calculation
 
         # Perform updates
         self.init_flows()
@@ -220,12 +227,12 @@ class People(cvb.BasePeople):
         ''' Check if they become infectious '''
         inds = self.check_inds(self.infectious, self.date_infectious, filter_inds=self.is_exp)
         self.infectious[inds] = True
-        self.infectious_strain[inds] = self.exposed_strain[inds]
-        for strain in range(self.pars['n_strains']):
-            this_strain_inds = cvu.itrue(self.infectious_strain[inds] == strain, inds)
-            n_this_strain_inds = len(this_strain_inds)
-            self.flows_strain['new_infectious_by_strain'][strain] += n_this_strain_inds
-            self.infectious_by_strain[strain, this_strain_inds] = True
+        self.infectious_variant[inds] = self.exposed_variant[inds]
+        for variant in range(self.pars['n_variants']):
+            this_variant_inds = cvu.itrue(self.infectious_variant[inds] == variant, inds)
+            n_this_variant_inds = len(this_variant_inds)
+            self.flows_variant['new_infectious_by_variant'][variant] += n_this_variant_inds
+            self.infectious_by_variant[variant, this_variant_inds] = True
         return len(inds)
 
 
@@ -271,28 +278,19 @@ class People(cvb.BasePeople):
         self.severe[inds]           = False
         self.critical[inds]         = False
         self.recovered[inds]        = True
-        self.recovered_strain[inds] = self.exposed_strain[inds]
-        self.infectious_strain[inds] = np.nan
-        self.exposed_strain[inds]    = np.nan
-        self.exposed_by_strain[:, inds] = False
-        self.infectious_by_strain[:, inds] = False
+        self.recovered_variant[inds] = self.exposed_variant[inds]
+        self.infectious_variant[inds] = np.nan
+        self.exposed_variant[inds]    = np.nan
+        self.exposed_by_variant[:, inds] = False
+        self.infectious_by_variant[:, inds] = False
 
 
         # Handle immunity aspects
         if self.pars['use_waning']:
 
-            # Before letting them recover, store information about the strain they had, store symptoms and pre-compute nabs array
-            mild_inds   = self.check_inds(self.susceptible, self.date_symptomatic, filter_inds=inds)
-            severe_inds = self.check_inds(self.susceptible, self.date_severe,      filter_inds=inds)
-
             # Reset additional states
             self.susceptible[inds] = True
             self.diagnosed[inds]   = False # Reset their diagnosis state because they might be reinfected
-            self.prior_symptoms[inds]        = self.pars['rel_imm_symp']['asymp']
-            self.prior_symptoms[mild_inds]   = self.pars['rel_imm_symp']['mild']
-            self.prior_symptoms[severe_inds] = self.pars['rel_imm_symp']['severe']
-            if len(inds):
-                cvi.init_nab(self, inds, prior_inf=True)
 
         return len(inds)
 
@@ -312,9 +310,9 @@ class People(cvb.BasePeople):
         self.known_contact[inds]    = False
         self.quarantined[inds]      = False
         self.recovered[inds]        = False
-        self.infectious_strain[inds] = np.nan
-        self.exposed_strain[inds]    = np.nan
-        self.recovered_strain[inds]  = np.nan
+        self.infectious_variant[inds] = np.nan
+        self.exposed_variant[inds]    = np.nan
+        self.recovered_variant[inds]  = np.nan
         return len(inds), len(diag_inds)
 
 
@@ -363,33 +361,38 @@ class People(cvb.BasePeople):
 
     #%% Methods to make events occur (infection and diagnosis)
 
-    def make_naive(self, inds):
+    def make_naive(self, inds, reset_vx=False):
         '''
         Make a set of people naive. This is used during dynamic resampling.
+
+        Args:
+            inds (array): list of people to make naive
+            reset_vx (bool): whether to reset vaccine-derived immunity
         '''
         for key in self.meta.states:
             if key in ['susceptible', 'naive']:
                 self[key][inds] = True
             else:
-                self[key][inds] = False
+                if (key != 'vaccinated') or reset_vx: # Don't necessarily reset vaccination
+                    self[key][inds] = False
 
-        # Reset strain states
-        for key in self.meta.strain_states:
+        # Reset variant states
+        for key in self.meta.variant_states:
             self[key][inds] = np.nan
-        for key in self.meta.by_strain_states:
+        for key in self.meta.by_variant_states:
             self[key][:, inds] = False
 
         # Reset immunity and antibody states
+        non_vx_inds = inds if reset_vx else inds[~self['vaccinated'][inds]]
         for key in self.meta.imm_states:
-            self[key][:, inds] = 0
-        for key in self.meta.nab_states:
-            self[key][inds] = np.nan
-        for key in self.meta.vacc_states:
-            self[key][inds] = 0
+            self[key][:, non_vx_inds] = 0
+        for key in self.meta.nab_states + self.meta.vacc_states:
+            self[key][non_vx_inds] = 0
 
         # Reset dates
         for key in self.meta.dates + self.meta.durs:
-            self[key][inds] = np.nan
+            if (key != 'date_vaccinated') or reset_vx: # Don't necessarily reset vaccination
+                self[key][inds] = np.nan
 
         return
 
@@ -415,7 +418,7 @@ class People(cvb.BasePeople):
 
 
 
-    def infect(self, inds, hosp_max=None, icu_max=None, source=None, layer=None, strain=0):
+    def infect(self, inds, hosp_max=None, icu_max=None, source=None, layer=None, variant=0):
         '''
         Infect people and determine their eventual outcomes.
 
@@ -423,6 +426,7 @@ class People(cvb.BasePeople):
             * Infected people that develop symptoms are disaggregated into mild vs. severe (=requires hospitalization) vs. critical (=requires ICU)
             * Every asymptomatic, mildly symptomatic, and severely symptomatic person recovers
             * Critical cases either recover or die
+            * If the simulation is being run with waning, this method also sets/updates agents' neutralizing antibody levels
 
         Method also deduplicates input arrays in case one agent is infected many times
         and stores who infected whom in infection_log list.
@@ -433,12 +437,15 @@ class People(cvb.BasePeople):
             icu_max  (bool):  whether or not there is an ICU bed available for this person
             source   (array): source indices of the people who transmitted this infection (None if an importation or seed infection)
             layer    (str):   contact layer this infection was transmitted on
-            strain   (int):   the strain people are being infected by
+            variant   (int):   the variant people are being infected by
 
         Returns:
             count (int): number of people infected
         '''
 
+        if len(inds) == 0:
+            return 0
+
         # Remove duplicates
         inds, unique = np.unique(inds, return_index=True)
         if source is not None:
@@ -450,37 +457,42 @@ class People(cvb.BasePeople):
         if source is not None:
             source = source[keep]
 
-        if self.pars['use_waning']:
-            cvi.check_immunity(self, strain, sus=False, inds=inds)
-
-        # Deal with strain parameters
-        strain_keys = ['rel_symp_prob', 'rel_severe_prob', 'rel_crit_prob', 'rel_death_prob']
-        infect_pars = {k:self.pars[k] for k in strain_keys}
-        if strain:
-            strain_label = self.pars['strain_map'][strain]
-            for k in strain_keys:
-                infect_pars[k] *= self.pars['strain_pars'][strain_label][k]
+        # Deal with variant parameters
+        variant_keys = ['rel_symp_prob', 'rel_severe_prob', 'rel_crit_prob', 'rel_death_prob']
+        infect_pars = {k:self.pars[k] for k in variant_keys}
+        variant_label = self.pars['variant_map'][variant]
+        if variant:
+            for k in variant_keys:
+                infect_pars[k] *= self.pars['variant_pars'][variant_label][k]
 
         n_infections = len(inds)
         durpars      = self.pars['dur']
 
-        # Update states, strain info, and flows
+        # Retrieve those with a breakthrough infection (defined nabs)
+        breakthrough_inds = inds[cvu.true(self.peak_nab[inds])]
+        if len(breakthrough_inds):
+            no_prior_breakthrough = (self.n_breakthroughs[breakthrough_inds] == 0) # We only adjust transmissibility for the first breakthrough
+            new_breakthrough_inds = breakthrough_inds[no_prior_breakthrough]
+            self.rel_trans[new_breakthrough_inds] *= self.pars['trans_redux']
+
+        # Update states, variant info, and flows
         self.susceptible[inds]    = False
         self.naive[inds]          = False
         self.recovered[inds]      = False
         self.diagnosed[inds]      = False
         self.exposed[inds]        = True
-        self.exposed_strain[inds] = strain
-        self.exposed_by_strain[strain, inds] = True
+        self.n_infections[inds]  += 1
+        self.n_breakthroughs[breakthrough_inds] += 1
+        self.exposed_variant[inds] = variant
+        self.exposed_by_variant[variant, inds] = True
         self.flows['new_infections']   += len(inds)
         self.flows['new_reinfections'] += len(cvu.defined(self.date_recovered[inds])) # Record reinfections
-        self.flows_strain['new_infections_by_strain'][strain] += len(inds)
-        # print('HI DEBUG', self.t, len(inds), len(cvu.defined(self.date_recovered[inds])))
-        # self.date_recovered[inds] = np.nan # Reset date they recovered - we only store the last recovery # TODO CK
+        self.flows_variant['new_infections_by_variant'][variant] += len(inds)
 
         # Record transmissions
         for i, target in enumerate(inds):
-            self.infection_log.append(dict(source=source[i] if source is not None else None, target=target, date=self.t, layer=layer))
+            entry = dict(source=source[i] if source is not None else None, target=target, date=self.t, layer=layer, variant=variant_label)
+            self.infection_log.append(entry)
 
         # Calculate how long before this person can infect other people
         self.dur_exp2inf[inds] = cvu.sample(**durpars['exp2inf'], size=n_infections)
@@ -492,10 +504,11 @@ class People(cvb.BasePeople):
             self[key][inds] = np.nan
 
         # Use prognosis probabilities to determine what happens to them
-        symp_probs = infect_pars['rel_symp_prob']*self.symp_prob[inds]*(1-self.symp_imm[strain, inds]) # Calculate their actual probability of being symptomatic
+        symp_probs = infect_pars['rel_symp_prob']*self.symp_prob[inds]*(1-self.symp_imm[variant, inds]) # Calculate their actual probability of being symptomatic
         is_symp = cvu.binomial_arr(symp_probs) # Determine if they develop symptoms
         symp_inds = inds[is_symp]
         asymp_inds = inds[~is_symp] # Asymptomatic
+        self.flows_variant['new_symptomatic_by_variant'][variant] += len(symp_inds)
 
         # CASE 1: Asymptomatic: may infect others, but have no symptoms and do not die
         dur_asym2rec = cvu.sample(**durpars['asym2rec'], size=len(asymp_inds))
@@ -506,11 +519,11 @@ class People(cvb.BasePeople):
         n_symp_inds = len(symp_inds)
         self.dur_inf2sym[symp_inds] = cvu.sample(**durpars['inf2sym'], size=n_symp_inds) # Store how long this person took to develop symptoms
         self.date_symptomatic[symp_inds] = self.date_infectious[symp_inds] + self.dur_inf2sym[symp_inds] # Date they become symptomatic
-        sev_probs = infect_pars['rel_severe_prob'] * self.severe_prob[symp_inds]*(1-self.sev_imm[strain, symp_inds]) # Probability of these people being severe
-        # print(self.sev_imm[strain, inds])
+        sev_probs = infect_pars['rel_severe_prob'] * self.severe_prob[symp_inds]*(1-self.sev_imm[variant, symp_inds]) # Probability of these people being severe
         is_sev = cvu.binomial_arr(sev_probs) # See if they're a severe or mild case
         sev_inds = symp_inds[is_sev]
         mild_inds = symp_inds[~is_sev] # Not severe
+        self.flows_variant['new_severe_by_variant'][variant] += len(sev_inds)
 
         # CASE 2.1: Mild symptoms, no hospitalization required and no probability of death
         dur_mild2rec = cvu.sample(**durpars['mild2rec'], size=len(mild_inds))
@@ -549,6 +562,11 @@ class People(cvb.BasePeople):
         self.dur_disease[dead_inds] = self.dur_exp2inf[dead_inds] + self.dur_inf2sym[dead_inds] + self.dur_sym2sev[dead_inds] + self.dur_sev2crit[dead_inds] + dur_crit2die   # Store how long this person had COVID-19
         self.date_recovered[dead_inds] = np.nan # If they did die, remove them from recovered
 
+        # Handle immunity aspects
+        if self.pars['use_waning']:
+            symp = dict(asymp=asymp_inds, mild=mild_inds, sev=sev_inds)
+            cvi.update_peak_nab(self, inds, nab_pars=self.pars, symp=symp)
+
         return n_infections # For incrementing counters
 
 
@@ -580,7 +598,7 @@ class People(cvb.BasePeople):
         self.date_diagnosed[final_inds] = self.t + test_delay
         self.date_pos_test[final_inds] = self.t
 
-        return
+        return final_inds
 
 
     def schedule_quarantine(self, inds, start_date=None, period=None):
@@ -709,6 +727,7 @@ class People(cvb.BasePeople):
                 'date_severe'         : 'developed severe symptoms and needed hospitalization',
                 'date_symptomatic'    : 'became symptomatic',
                 'date_tested'         : 'was tested for COVID',
+                'date_vaccinated'     : 'was vaccinated against COVID',
             }
 
             for attribute, message in dates.items():
