@@ -7,10 +7,10 @@ at the heart of the integration loop.
 
 #%% Housekeeping
 
-import numba  as nb # For faster computations
-import numpy  as np # For numerics
+import numba as nb # For faster computations
+import numpy as np # For numerics
 import random # Used only for resetting the seed
-import scipy.stats as sps # For distributions
+import sciris as sc # For additional utilities
 from .settings import options as cvo # To set options
 from . import defaults as cvd # To set default types
 
@@ -90,27 +90,42 @@ def compute_trans_sus(rel_trans,  rel_sus,    inf,       sus,       beta_layer,
     return rel_trans, rel_sus
 
 
-@nb.njit(             (nbfloat,  nbint[:], nbint[:],  nbfloat[:],  nbfloat[:], nbfloat[:]), cache=cache, parallel=rand_parallel)
-def compute_infections(beta,     sources,  targets,   layer_betas, rel_trans,  rel_sus): # pragma: no cover
+@nb.njit(             (nbfloat,  nbint[:],  nbint[:], nbfloat[:],   nbfloat[:], nbfloat[:], nbbool), cache=cache, parallel=rand_parallel)
+def compute_infections(beta,     p1,        p2,       layer_betas,  rel_trans,  rel_sus,    legacy=False): # pragma: no cover
     '''
     Compute who infects whom
 
-    The heaviest step of the model, taking about 50% of the total time -- figure
-    out who gets infected on this timestep. Cannot be easily parallelized since
-    random numbers are used.
+    The heaviest step of the model -- figure out who gets infected on this timestep.
+    Cannot be easily parallelized since random numbers are used. Loops over contacts
+    in both directions (i.e., targets become sources).
+
+    Args:
+        beta: overall transmissibility
+        p1: person 1
+        p2: person 2
+        layer_betas: per-contact transmissibilities
+        rel_trans: the source's relative transmissibility
+        rel_sus: the target's relative susceptibility
+        legacy: whether to use the slower legacy (pre 3.1.1) calculation method
     '''
-    source_trans     = rel_trans[sources] # Pull out the transmissibility of the sources (0 for non-infectious people)
-    inf_inds         = source_trans.nonzero()[0] # Infectious indices -- remove noninfectious people
-    betas            = beta * layer_betas[inf_inds] * source_trans[inf_inds] * rel_sus[targets[inf_inds]] # Calculate the raw transmission probabilities
-    nonzero_inds     = betas.nonzero()[0] # Find nonzero entries
-    nonzero_inf_inds = inf_inds[nonzero_inds] # Map onto original indices
-    nonzero_betas    = betas[nonzero_inds] # Remove zero entries from beta
-    nonzero_sources  = sources[nonzero_inf_inds] # Remove zero entries from the sources
-    nonzero_targets  = targets[nonzero_inf_inds] # Remove zero entries from the targets
-    transmissions    = (np.random.random(len(nonzero_betas)) < nonzero_betas).nonzero()[0] # Compute the actual infections!
-    source_inds      = nonzero_sources[transmissions]
-    target_inds      = nonzero_targets[transmissions] # Filter the targets on the actual infections
-    return source_inds, target_inds
+    slist = np.empty(0, dtype=nbint)
+    tlist = np.empty(0, dtype=nbint)
+    pairs = [[p1,p2], [p2,p1]] if not legacy else [[p1,p2]]
+    for sources,targets in pairs:
+        source_trans     = rel_trans[sources] # Pull out the transmissibility of the sources (0 for non-infectious people)
+        inf_inds         = source_trans.nonzero()[0] # Infectious indices -- remove noninfectious people
+        betas            = beta * layer_betas[inf_inds] * source_trans[inf_inds] * rel_sus[targets[inf_inds]] # Calculate the raw transmission probabilities
+        nonzero_inds     = betas.nonzero()[0] # Find nonzero entries
+        nonzero_inf_inds = inf_inds[nonzero_inds] # Map onto original indices
+        nonzero_betas    = betas[nonzero_inds] # Remove zero entries from beta
+        nonzero_sources  = sources[nonzero_inf_inds] # Remove zero entries from the sources
+        nonzero_targets  = targets[nonzero_inf_inds] # Remove zero entries from the targets
+        transmissions    = (np.random.random(len(nonzero_betas)) < nonzero_betas).nonzero()[0] # Compute the actual infections!
+        source_inds      = nonzero_sources[transmissions]
+        target_inds      = nonzero_targets[transmissions] # Filter the targets on the actual infections
+        slist = np.concatenate((slist, source_inds), axis=0)
+        tlist = np.concatenate((tlist, target_inds), axis=0)
+    return slist, tlist
 
 
 @nb.njit((nbint[:], nbint[:], nb.int64[:]), cache=cache)
@@ -215,8 +230,7 @@ def sample(dist=None, par1=None, par2=None, size=None, **kwargs):
         if '_int' in dist:
             samples = np.round(samples)
     else:
-        choicestr = '\n'.join(choices)
-        errormsg = f'The selected distribution "{dist}" is not implemented; choices are: {choicestr}'
+        errormsg = f'The selected distribution "{dist}" is not implemented; choices are: {sc.newlinejoin(choices)}'
         raise NotImplementedError(errormsg)
 
     return samples
@@ -230,12 +244,13 @@ def get_pdf(dist=None, par1=None, par2=None):
     symptom-to-swab for testing. For example, for Washington State, these values
     are dist='lognormal', par1=10, par2=170.
     '''
+    import scipy.stats as sps # Import here since slow
 
     choices = [
         'none',
         'uniform',
         'lognormal',
-        ]
+    ]
 
     if dist in ['None', 'none', None]:
         return None
@@ -651,4 +666,4 @@ def iundefinedi(arr, inds):
 
         inds = cv.iundefinedi(np.array([4,np.nan,0,np.nan,np.nan,4,7,4,np.nan]), inds=np.array([0,1,3,5]))
     '''
-    return inds[np.isnan(arr[inds])]
\ No newline at end of file
+    return inds[np.isnan(arr[inds])]
